<template>
  <el-dialog
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="100px"
      class="l-mes"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="库位号" prop="locName">
            <el-input v-model="dataForm.locName" placeholder="库位号" readonly>
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openLocationDialog()"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="库位描述" prop="locDesc">
            <el-input
              v-model="dataForm.locDesc"
              placeholder="库位描述"
              readonly
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="库位类型" prop="locType">
            <el-input v-model="locTypeStr" placeholder="库位类型" readonly />
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="库位分组" prop="locGroup">
            <el-input
              v-model="dataForm.locGroup"
              placeholder="库位分组"
              readonly
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="备注" prop="locRemark">
            <el-input
              v-model="dataForm.locRemark"
              placeholder="备注"
              readonly
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="零件" prop="partId">
            <el-input v-model="dataForm.partNo" placeholder="" readonly>
              <el-button
                slot="append"
                icon="el-icon-search"
                @click="openPartDialog()"
              ></el-button>
            </el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="最高安全库存" prop="highQty">
            <el-input
              v-model="dataForm.highQty"
              placeholder="最高安全库存"
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="最低安全库存" prop="lowQty">
            <el-input
              v-model="dataForm.lowQty"
              placeholder="最低安全库存"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="申请批量" prop="batchQty">
            <el-input
              v-model="dataForm.batchQty"
              placeholder="申请批量"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>
    <part-dialog
      :currshowlist.sync="showPart"
      @listenToPartEvent="selectPart"
    />
    <locationDialog
      :currshowlist.sync="showLocation"
      @listenToLocationEvent="selectLocation"
    />
  </el-dialog>
</template>

<script>
import { getObj, addObj, putObj } from '@/api/warehouse/stockmain'
import locationDialog from '@/views/common/location.vue'
import PartDialog from '@/views/common/part'
import { remote } from '../../../api/admin/dict'
export default {
  components: {
    locationDialog,
    PartDialog
  },
  data() {
    return {
      showPart: false,
      showLocation: false,
      visible: false,
      dataForm: {
        id: 0,
        partId: '',
        safetyStockId: '',
        highQty: '',
        lowQty: '',
        batchQty: '',
        partOptList: [],
        locName: ''
      },
      dataRule: {
        locName: [
          { required: true, message: '库位编号不能为空', trigger: 'blur' }
        ],
        partId: [{ required: true, message: '零件不能为空', trigger: 'blur' }],
        highQty: [
          { required: true, message: '最高安全库存不能为空', trigger: 'blur' }
        ],
        lowQty: [
          { required: true, message: '最低安全库存不能为空', trigger: 'blur' }
        ],
        batchQty: [
          { required: true, message: '申请批量不能为空', trigger: 'blur' }
        ]
      },
      components: [],
      partList: [],
      locTypeOptions: [],
      isSubmit: false
    }
  },
  created() {
    this.getLocTypeCache('warehouse_type') // 获取安全库存任务运行时的库位类型
  },
  computed: {
    locTypeStr() {
      return this.getLocType(this.dataForm.locType)
    }
  },
  methods: {
    /**
     * 获取字典显示名称并缓存
     */
    getLocTypeCache(type) {
      remote(type).then((response) => {
        const code = response.data.code
        if (code === 0) {
          const _data = response.data.data
          this.locTypeOptions = _data
        }
      })
    },
    /**
     * 获取字典定时任务执行状态字典值显示名称
     */
    getLocType(value) {
      let re = ''
      this.locTypeOptions.forEach((obj) => {
        if (obj.value === value) {
          re = obj.label
        }
      })
      return re
    },
    // 库位弹窗
    openLocationDialog() {
      this.showLocation = true
    },
    selectLocation(location) {
      if (location) {
        this.dataForm.safetyStockId = location.id
        this.dataForm.locName = location.locName
        this.dataForm.locDesc = location.locDesc
        this.dataForm.locType = location.locType
        this.dataForm.locGroup = location.locGroup
        this.dataForm.locRemark = location.locRemark
        this.$refs.dataForm.validateField('safetyStockId', (valid) => {})
      }
    },
    // 零件选择
    openPartDialog() {
      this.showPart = true
    },
    selectPart(part) {
      if (part) {
        this.dataForm.partId = part.id
        this.dataForm.partNo = part.partNo
        this.$refs.dataForm.validateField('partId', (valid) => {})
      }
    },
    init(id) {
      this.dataForm.id = id || 0
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = response.data.data
          })
        }
      })
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          if (this.dataForm.id) {
            this.dataForm.partOptList = this.partList
            putObj(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          } else {
            this.dataForm.partOptList = this.partList
            addObj(this.dataForm).then((data) => {
              this.$message.success('添加成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          }
        } else {
          this.isSubmit = false
        }
      })
    }
  }
}
</script>
